const enableColumnHighlighting = () => {
  const table = document.querySelector('#schedules');
  const highlightInputs = document.querySelectorAll('input[name="highlight-schedule"]');

  highlightInputs.forEach(input => input.addEventListener('change', event => {
    const checkedInput = event.target;
    const highlight = checkedInput.value;
    if (highlight === 'none') {
      table.classList.remove('highlight');
      table.querySelectorAll('.highlight')
        .forEach(td => td.classList.remove('highlight'));
    } else {
      table.classList.add('highlight');
      table.querySelectorAll('.highlight')
        .forEach(td => td.classList.remove('highlight'));
      const scheduleHeader = checkedInput.closest('th');
      const scheduleIndex = [...scheduleHeader.parentNode.children].indexOf(scheduleHeader);
      table.querySelectorAll(`td:nth-child(${scheduleIndex + 1}), .schedule-time.${highlight}`)
        .forEach(element => element.classList.add('highlight'));

      table.querySelectorAll('tbody td:first-child')
        .forEach(element => {
          const highlightedColumnInSameRow = [...element.closest('tr').children][scheduleIndex];
          const shouldHighlightElement = highlightedColumnInSameRow.classList.contains('schedule');
          element.classList.toggle('highlight', shouldHighlightElement);
        });
    }
  }));
}

const enableColumnSorting = () => {
  const triggers = document.querySelectorAll('.sort-by-trigger');
  const tbody = document.querySelector('tbody');

  const firstRowTds = () => [...tbody.querySelectorAll('tr:first-child > td')];
  const getColumnText = (row, index) => row.children.item(index).innerText;

  triggers.forEach(trigger => trigger.addEventListener('click', event => {
    event.preventDefault();
    const clickedTrigger = event.target;
    const headerRow = clickedTrigger.closest('tr');
    const targetHeader = clickedTrigger.closest('th');
    const columnIndex = [...headerRow.children].indexOf(targetHeader);
    firstRowTds().forEach(td => td.classList.remove('sort-by'));

    [...tbody.querySelectorAll('tr')]
      .sort((rowA, rowB) => {
        const textA = getColumnText(rowA, columnIndex);
        const textB = getColumnText(rowB, columnIndex);
        if (textA === textB) return 0;
        if (textA === '') return 1;
        if (textB === '') return -1;
        return textA.localeCompare(textB);
      })
      .forEach(row => tbody.appendChild(row));

    firstRowTds()[columnIndex].classList.add('sort-by');
    clickedTrigger.blur();
  }));
}

enableColumnHighlighting();
enableColumnSorting();
